Unit

Enum Unit 

pub enum Unit {
    Byte,
    Bit,
}
Whether a range’s two ends count bytes or bits.

BITCOUNT and BITPOS both take an optional BYTE or BIT word after their two indexes, and both default to BYTE. The word is only allowed once both indexes are there: BITPOS k 0 5 BIT is not a bit ranged search from bit five, it is an error, because BIT is read as the end index.

Variants



Byte

Indexes count bytes. The default.



Bit

Indexes count bits.