count_range

Function count_range 

pub fn count_range(bytes: &[u8], from: u64, to: u64) -> u64
How many bits are set in the half open bit range from..to.

Both ends are bit indexes and the caller has already clamped them to the bitmap, which is where the negative index and the BYTE or BIT word are dealt with. An empty or backwards range is zero.