set

Function set 

pub fn set(bytes: &mut [u8], at: u64, f: Field, val: i64)
Write val into the field of f bits at bit at.

Panics

If the slice does not reach the end of the field. Growing the value is the caller’s job, because only the caller knows whether it is allowed to.