pub enum Compare<'a> {
Equal(&'a [u8]),
NotEqual(&'a [u8]),
DigestEqual(u64),
DigestNotEqual(u64),
}Expand description
What a conditional write compares the current value against.
Variants
Equal(&'a [u8])
IFEQ: the value is exactly these bytes.
NotEqual(&'a [u8])
IFNE: the value is not exactly these bytes, or there is no value.
DigestEqual(u64)
IFDEQ: the value’s digest is this number.
DigestNotEqual(u64)
IFDNE: the value’s digest is not this number, or there is no value.
Implementations