Element

Type Alias Element 

pub type Element<'a> = Entry<'a>;
A list element: bytes as they lie, or an integer not yet formatted.

Aliased Type

pub enum Element<'a> {
    Int(i64),
    Str(&'a [u8]),
}

Variants



Int(i64)

Stored as an integer, in one of the six integer encodings.



Str(&'a [u8])

Stored as bytes.