By

Enum By 

pub enum By<'a> {
    Rank {
        start: i64,
        stop: i64,
    },
    Score {
        min: Bound,
        max: Bound,
    },
    Lex {
        min: Lex<'a>,
        max: Lex<'a>,
    },
}
What a range is measured in.

Variants



Rank

Positions, where a negative one counts from the end. ZRANGE k 0 -1.

Fields

start: i64

The first position, inclusive.

stop: i64

The last position, inclusive.



Score

Scores. ZRANGEBYSCORE, and ZRANGE ... BYSCORE.

Fields

min: Bound

The lowest score wanted.

max: Bound

The highest score wanted.



Lex

Members, which is only meaningful when every score is the same. ZRANGEBYLEX, and ZRANGE ... BYLEX.

Fields

min: Lex<'a>

The first member wanted.

max: Lex<'a>

The last member wanted.