pub fn write_cold_record(
out: &mut [u8],
kind: Kind,
enc: Encoding,
at: Addr,
len: u32,
expire_at: Option<u64>,
)Expand description
Write a record saying the value is at at on the file and is len bytes.
out must be exactly cold_record_len long. kind and enc are carried
across from the record being replaced so that the questions which can be
answered without the device still can be.